@@ -16,16 +16,24 @@ from .const import READ_CHARACTERISTIC, WRITE_CHARACTERISTIC
 _LOGGER = logging.getLogger(__name__)
 
 
-class AuthError(Exception):
-    pass
+class YaleXSBLEError(Exception):
+    """Base class for YaleXSBLE errors."""
 
 
-class ResponseError(Exception):
-    pass
+class AuthError(YaleXSBLEError):
+    """Error during authentication."""
 
 
-class DisconnectedError(Exception):
-    pass
+class ResponseError(YaleXSBLEError):
+    """Error during response."""
+
+
+class DisconnectedError(YaleXSBLEError):
+    """Disconnected during response."""
+
+
+class NoAdvertisementError(YaleXSBLEError):
+    """No advertisement data."""
 
 
 class Session:
@@ -57,6 +65,7 @@ class Session:
         self._notify_future: asyncio.Future[bytes] | None = None
         self._state_callback = state_callback
         self._disconnected_event = disconnected_event
+        self._first_request = True
 
     def set_key(self, key: bytes) -> None:
         self.cipher_encrypt = AES.new(key, AES.MODE_CBC, iv=bytes(0x10))
@@ -226,9 +235,15 @@ class Session:
             try:
                 return await write_task
             except BleakError as err:
+                if self._first_request and util.is_key_error(err):
+                    raise AuthError(
+                        f"Authentication error: key or slot (key index) is incorrect: {err}"
+                    ) from err
                 if util.is_disconnected_error(err):
                     raise DisconnectedError(f"{self.name}: {err}") from err
                 raise
+            finally:
+                self._first_request = False
         write_task.cancel()
         with contextlib.suppress(asyncio.CancelledError, Exception):
             await write_task
